/***************************************************************
 * Name:      choice.cpp
 * Purpose:   Code for Dialog choice
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-23
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "choice.h"

IMPLEMENT_DYNAMIC_CLASS( chValidator, wxValidator )
BEGIN_EVENT_TABLE( chValidator, wxValidator )
END_EVENT_TABLE()

chValidator::chValidator(wxString *v) : wxValidator(), m_valor(v) {}

bool chValidator::TransferFromWindow()
{
    try {
        wxChoice *lb = dynamic_cast<wxChoice*>(m_validatorWindow);
        int s = lb->GetSelection();
        if(s != wxNOT_FOUND) *m_valor = lb->GetString(s);
        else *m_valor = "";
    }
    catch (...) {
        wxFAIL_MSG( _T("chValidator sólo funciona con wxListBox"));
        return false;
    }
    return true;
}

bool chValidator::TransferToWindow()
{
    try {
        wxChoice *lb = dynamic_cast<wxChoice*>(m_validatorWindow);
        lb->SetStringSelection(*m_valor);
    }
    catch(...) {
        wxFAIL_MSG( _T("chValidator sólo funciona con wxListBox"));
        return false;
    }
    return true;
}

bool chValidator::Validate(wxWindow* parent)
{
//    if (!m_validatorWindow->IsEnabled()) return true;
    return true;
}

wxBEGIN_EVENT_TABLE(choice, wxDialog)
    EVT_CLOSE(choice::OnClose)
wxEND_EVENT_TABLE()

choice::choice(wxWindow *wnd, datosChoice &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de choice")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxString cads[] = {
        _T("Óptimo"),
        _T("Muy bueno"),
        _T("Bueno"),
        _T("Aceptable"),
        _T("Regular"),
        _T("Malo"),
        _T("Muy malo"),
        _T("Pésimo")
    };

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_choice = new wxChoice(this, idChoice, wxDefaultPosition, wxSize(200, wxDefaultCoord), sizeof(cads)/sizeof(cads[0]), cads, 0, chValidator(&data.opcion));
    boxHorizontal->Add(m_choice, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

choice::~choice()
{
    //dtor
}

void choice::OnClose(wxCloseEvent& event) {
    Destroy();
}


