/***************************************************************
 * Name:      cliendata.cpp
 * Purpose:   Code for Dialog listbox con clientdata
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-24
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "cliendata.h"

IMPLEMENT_DYNAMIC_CLASS( cdValidator, wxValidator )
BEGIN_EVENT_TABLE( cdValidator, wxValidator )
END_EVENT_TABLE()

bool cdValidator::TransferFromWindow()
{
    try {
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        int s = lb->GetSelection();
        if(s != wxNOT_FOUND) {
            colorClientData* ccd = static_cast<colorClientData*>(lb->GetClientObject(s));
            *m_valor = ccd->GetData();
        }
        else *m_valor = 0;
    }
    catch (...) {
        wxFAIL_MSG( _T("cdValidator sólo funciona con wxListBox con datos de cliente"));
        return false;
    }
    return true;
}

bool cdValidator::TransferToWindow()
{
    try {
        size_t i;
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        colorClientData* ccd;
        for(i=0; i<lb->GetCount(); i++) {
            ccd = static_cast<colorClientData*>(lb->GetClientObject(i));
            wxUint32 v = ccd->GetData();
            if(v == *m_valor) break;
        }
        if(i < lb->GetCount()) lb->SetSelection(i);
    }
    catch(...) {
        wxFAIL_MSG( _T("cdValidator sólo funciona con wxListBox con datos de cliente"));
        return false;
    }
    return true;
}

bool cdValidator::Validate(wxWindow* parent)
{
    return true;
}

wxBEGIN_EVENT_TABLE(cliendata, wxDialog)
    EVT_CLOSE(cliendata::OnClose)
wxEND_EVENT_TABLE()

cliendata::cliendata(wxWindow *wnd, datosClientData &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de cliendata")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    std::vector<tipoOpcion> opciones = {
        {_T("Rojo"),        0xff0000},
        {_T("Naranja"),     0xff8000},
        {_T("Amarillo"),    0xffff00},
        {_T("Verde"),       0x00ff00},
        {_T("Azul"),        0x0000ff},
        {_T("Añil"),        0x00ffff},
        {_T("Violeta"),     0xff00ff}
        };

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_listBox = new wxListBox(this, idListBox, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, nullptr, wxLB_SORT, cdValidator(&data.opcion));
    for(size_t i=0; i<opciones.size(); i++) {
        m_listBox->Append(opciones[i].nombre, new colorClientData(opciones[i].rgb));
    }
    boxHorizontal->Add(m_listBox, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

cliendata::~cliendata()
{
    //dtor
}

void cliendata::OnClose(wxCloseEvent& event) {
    Destroy();
}
