/***************************************************************
 * Name:      listbox.cpp
 * Purpose:   Code for Dialog listbox
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-23
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "listbox.h"

IMPLEMENT_DYNAMIC_CLASS( lbValidator, wxValidator )
BEGIN_EVENT_TABLE( lbValidator, wxValidator )
END_EVENT_TABLE()

lbValidator::lbValidator(wxString *v) : wxValidator(), m_valor(v) {}

bool lbValidator::TransferFromWindow()
{
    try {
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        int s = lb->GetSelection();
        if(s != wxNOT_FOUND) *m_valor = lb->GetString(s);
        else *m_valor = "";
    }
    catch (...) {
        wxFAIL_MSG( _T("lbValidator sólo funciona con wxListBox"));
        return false;
    }
    return true;
}

bool lbValidator::TransferToWindow()
{
    try {
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        lb->SetStringSelection(*m_valor);
    }
    catch(...) {
        wxFAIL_MSG( _T("lbValidator sólo funciona con wxListBox"));
        return false;
    }
    return true;
}

bool lbValidator::Validate(wxWindow* parent)
{
//    if (!m_validatorWindow->IsEnabled()) return true;
    return true;
}

wxBEGIN_EVENT_TABLE(listbox, wxDialog)
    EVT_CLOSE(listbox::OnClose)
wxEND_EVENT_TABLE()

listbox::listbox(wxWindow *wnd, datosListBox &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de listbox")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    wxString cads[] = {
        _T("Rojo"),
        _T("Naranja"),
        _T("Amarillo"),
        _T("Verde"),
        _T("Azul"),
        _T("Añil"),
        _T("Violeta")
    };

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_listBox = new wxListBox(this, idListBox, wxDefaultPosition, wxSize(200, wxDefaultCoord), sizeof(cads)/sizeof(cads[0]), cads, 0, lbValidator(&data.opcion));
    m_listBox->Append(_T("Negro"));
    boxHorizontal->Add(m_listBox, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

listbox::~listbox()
{
    //dtor
}

void listbox::OnClose(wxCloseEvent& event) {
    Destroy();
}


