/***************************************************************
 * Name:      cliendata.cpp
 * Purpose:   Code for Dialog listbox de selección múltiple
 * Author:    Salvador Pozo (salvapozo@gmail.com)
 * Created:   2024-11-24
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#include "multiple.h"

IMPLEMENT_DYNAMIC_CLASS( mulValidator, wxValidator )
BEGIN_EVENT_TABLE( mulValidator, wxValidator )
END_EVENT_TABLE()

bool mulValidator::TransferFromWindow()
{
    try {
        wxArrayInt indices;
        multipleClientData* ccd;
        m_valores->Clear();
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        lb->GetSelections(indices);
        for(size_t i=0; i<indices.GetCount(); i++) {
            ccd = static_cast<multipleClientData*>(lb->GetClientObject(indices[i]));
            m_valores->Add(ccd->GetData());
        }
    }
    catch (...) {
        wxFAIL_MSG( _T("mulValidator sólo funciona con wxListBox de selección múltiple con datos de cliente"));
        return false;
    }
    return true;
}

bool mulValidator::TransferToWindow()
{
    try {
        size_t i;
        wxListBox *lb = dynamic_cast<wxListBox*>(m_validatorWindow);
        multipleClientData* ccd;
        for(i=0; i < lb->GetCount(); i++) {
            ccd = static_cast<multipleClientData*>(lb->GetClientObject(i));
            int v = ccd->GetData();
            for(size_t j=0; j < m_valores->GetCount(); j++) {
                if(m_valores->at(j) == v) lb->SetSelection(i);
            }
        }
    }
    catch(...) {
        wxFAIL_MSG( _T("mulValidator sólo funciona con wxListBox de selección múltiple con datos de cliente"));
        return false;
    }
    return true;
}

bool mulValidator::Validate(wxWindow* parent)
{
    return true;
}

wxBEGIN_EVENT_TABLE(multiple, wxDialog)
    EVT_CLOSE(multiple::OnClose)
wxEND_EVENT_TABLE()

multiple::multiple(wxWindow *wnd, datosMultiple &datos)
    : wxDialog(wnd, -1, _T("Ejemplo de listbox de selección multiple")), data(datos)
{
    wxBoxSizer *boxVertical;
    wxBoxSizer *boxHorizontal;
    std::vector<tipoOpcionMultiple> opciones = {
        {_T("Uno"),         1},
        {_T("Dos"),         2},
        {_T("Tres"),        3},
        {_T("Cuatro"),      4},
        {_T("Cinco"),       5},
        {_T("Seis"),        6},
        {_T("Siete"),       7}
        };

    boxVertical = new wxBoxSizer(wxVERTICAL);

    boxHorizontal = new wxBoxSizer(wxHORIZONTAL);
    m_listBox = new wxListBox(this, idListBox, wxDefaultPosition, wxSize(200, wxDefaultCoord), 0, nullptr, wxLB_MULTIPLE | wxLB_SORT, mulValidator(&data.opciones));
    for(size_t i=0; i<opciones.size(); i++) {
        m_listBox->Append(opciones[i].nombre, new multipleClientData(opciones[i].clave));
    }
    boxHorizontal->Add(m_listBox, wxSizerFlags().Border());
    boxVertical->Add(boxHorizontal, wxSizerFlags().Border(wxTOP).Right());

    boxVertical->Add(CreateStdDialogButtonSizer(wxOK | wxCANCEL), wxSizerFlags().Border());

    SetSizerAndFit(boxVertical);
}

multiple::~multiple()
{
    //dtor
}

void multiple::OnClose(wxCloseEvent& event) {
    Destroy();
}
