/***************************************************************
 * Name:      wx008Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-11-23
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif

#include "wx008Main.h"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx008Frame, wxFrame)
    EVT_CLOSE(wx008Frame::OnClose)
    EVT_MENU(idMenuQuit, wx008Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx008Frame::OnAbout)
    EVT_MENU(idMenuListBox, wx008Frame::OnListBox)
    EVT_MENU(idMenuClientData, wx008Frame::OnClientData)
    EVT_MENU(idMenuMultiple, wx008Frame::OnMultiple)
    EVT_MENU(idMenuChoice, wx008Frame::OnChoice)
END_EVENT_TABLE()

wx008Frame::wx008Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title),
    dataListBox(_T("Amarillo")),
    dataClientData(0xffff00),
    dataMultiple({3, 7, 1}),
    dataChoice("Regular")
{
    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));
    fileMenu->Append(idMenuListBox, _T("&ListBox"), _T("Ejemplo de listbox"));
    fileMenu->Append(idMenuClientData, _T("&ClientData"), _T("Ejemplo de listbox con datos de cliente"));
    fileMenu->Append(idMenuMultiple, _T("&Múltiple"), _T("Ejemplo de listbox con selección múltiple"));
    fileMenu->Append(idMenuChoice, _T("&Elección"), _T("Ejemplo de control wxChoice"));
    fileMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Abandonar la aplicación"));
    mbar->Append(fileMenu, _T("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _("&Sobre\tF1"), _T("Muestra información sobre la aplicación"));
    mbar->Append(helpMenu, _("&Ayuda"));

    SetMenuBar(mbar);

    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx008Frame::~wx008Frame()
{
}

void wx008Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx008Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx008Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _("Bienvenido a..."));
}

void wx008Frame::OnListBox(wxCommandEvent& event)
{
    listbox *dlg = new listbox(this, dataListBox);
    dlg->ShowModal();

    wxMessageBox(dataListBox.opcion, _T("Respuesta"));
}

void wx008Frame::OnClientData(wxCommandEvent& event)
{
    wxString cad="";
    cliendata *dlg = new cliendata(this, dataClientData);
    dlg->ShowModal();

    cad << dataClientData.opcion;
    wxMessageBox(cad, _T("Respuesta"));
}

void wx008Frame::OnMultiple(wxCommandEvent& event)
{
    wxString cad="";
    multiple *dlg = new multiple(this, dataMultiple);
    dlg->ShowModal();

    for(size_t i=0; i<dataMultiple.opciones.GetCount(); i++)
        cad << dataMultiple.opciones[i] << " ";
    wxMessageBox(cad, _T("Respuesta"));
}

void wx008Frame::OnChoice(wxCommandEvent& event)
{
    choice *dlg = new choice(this, dataChoice);
    dlg->ShowModal();

    wxMessageBox(dataChoice.opcion, _T("Respuesta"));
}
